## Generating Protobuf

`python -m grpc_tools.protoc --proto_path=. --python_out=. --grpc_python_out=. nedo_vision_training/protos/*.proto`

## Running

```
source /mnt/linux-data/nedo-vision/venv-training-agent/bin/activate

python3 -m nedo_vision_training.cli run --token 2bd8821d7aa8442d9f0fd77800566dfe --server-host localhost --rest-api-port 8081
```
